@@ -98,7 +98,7 @@ print.summary.plm <- function(x,digits=5,length.line=70,...){
 
   centre("Overall Statistics",length.line)
   cat(paste("Total Sum of Squares       : ",signif(x$tss,digits),"\n",sep=""))
-  cat(paste("Sum of Squares Residuals   : ",signif(x$ssr,digits),"\n",sep=""))
+  cat(paste("Residual Sum of Squares    : ",signif(x$ssr,digits),"\n",sep=""))
   cat(paste("Rsq                        : ",signif(x$rsq,digits),"\n",sep=""))
   cat(paste("F                          : ",signif(x$fstatistic$statistic),"\n",sep=""))
   cat(paste("P(F>0)                     : ",signif(x$fstatistic$p.value),"\n",sep=""))
